UnixFdStream

Struct UnixFdStream 

pub struct UnixFdStream<T: AsRawFd> { /* private fields */ }
A wrapper around a UnixStream that allows file descriptors to be sent and received with messages. Implements AsyncRead and AsyncWrite such that standard asynchronous reading and writing operations and helpers may be used.

Implementations

Source

impl<T: AsRawFd + NonBlocking> UnixFdStream<T>

pub fn new(unix: T, max_read_fds: usize) -> Result<Self>

Create a new UnixFdStream from a UnixStream which is also configured to read up to max_read_fds for each read from the socket.

The file descriptors that are transferred are buffered in a Vec<RawFd>, but only so many will have space made for them in the receiving header as configured by max_read_fds, other file descriptors sent beyond this limit will be discarded by the kernel. We do not check for the MSG_CTRUNC flag, therefore this will be a silent discard.

Source

impl<T: AsRawFd> UnixFdStream<T>

pub fn split<'a>(&'a mut self) -> (ReadHalf<'a, T>, WriteHalf<'a, T>)

pub fn into_split(self) -> (OwnedReadHalf<T>, OwnedWriteHalf<T>)

pub fn push_outgoing_fd<F: IntoRawFd>(&self, fd: F)

Push a file descriptor to be written with the next message that is written to this stream. The ownership is transferred and the file descriptor is either closed when the message is sent or this instance is dropped.

pub async fn readable(&self) -> Result<()>

Wait for the underlying UnixStream to become readable.

pub fn pop_incoming_fd(&self) -> Option<RawFd>

Get the most recent file descriptor that was read with a message.

pub fn incoming_count(&self) -> usize

Get the number of file descriptors in the incoming queue.